@@ -170,3 +170,13 @@ parse_all.default <- function(x, filename = NULL, ...) {
     filename <- "<expression>"
   parse_all(deparse(x), filename, ...)
 }
+
+# Calls are already parsed and always length one
+#' @export
+parse_all.call <- function(x, filename = NULL, ...) {
+  expr <- list(as.expression(x))
+  src <- deparse(x)
+  out <- data.frame(src = src, stringsAsFactors = FALSE)
+  out$expr <- expr
+  out
+}
